import sys
import argparse

from desmondtools import Maestro


def batch_cif():
    parser = argparse.ArgumentParser(description="COnvert Maestro file(s) to CIF file(s)",
    formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('mae', nargs='+', default=[], help='input maestro filename(s)')
    args = parser.parse_args()

    if len(args.mae) == 0:
        argparse.print_help()
        sys.exit(0)
    
    for filename in args.mae:
        u = Maestro(filename)
        u.convert_to_mmcif()


from .batch_desmond_setup import *
from .batch_desmond_md import *
from .batch_desmond_mdinfo import *
from .batch_desmond_cms2dcd import *

from .batch_desmond_min import *
from .batch_desmond_metad import *
from .batch_desmond_pli import *
from .batch_desmond_cif import *

from .schrodinger_run import *